@@ -66,7 +66,7 @@ use DNS::Unbound::X ();
 our ($VERSION);
 
 BEGIN {
-    $VERSION = '0.14_01';
+    $VERSION = '0.16_01';
     XSLoader::load();
 }
 
@@ -483,6 +483,53 @@ sub count_pending_queries {
 
 #----------------------------------------------------------------------
 
+=head1 METHODS FOR DEALING WITH DNSSEC
+
+The following correspond to their equivalents in libunbound
+and will only work if the underlying libunbound version supports them.
+
+=head2 I<OBJ>->add_ta()
+
+Z<>
+
+=cut
+
+sub add_ta {
+    return _ub_ctx_add_ta( $_[0]->{'_ub'}, $_[1] );
+}
+
+=head2 I<OBJ>->add_ta_autr()
+
+Z<>
+
+=cut
+
+sub add_ta_autr {
+    return _ub_ctx_add_ta_autr( $_[0]->{'_ub'}, $_[1] );
+}
+
+=head2 I<OBJ>->add_ta_file()
+
+Z<>
+
+=cut
+
+sub add_ta_file {
+    return _ub_ctx_add_ta_file( $_[0]->{'_ub'}, $_[1] );
+}
+
+=head2 I<OBJ>->trustedkeys()
+
+Z<>
+
+=cut
+
+sub trustedkeys {
+    return _ub_ctx_trustedkeys( $_[0]->{'_ub'}, $_[1] );
+}
+
+#----------------------------------------------------------------------
+
 sub _check_promises {
     my ($self) = @_;
 
